@@ -152,9 +152,9 @@ class Context:
   def _instantiate(self, module, cls, args):
     logging.info(f"[+] Object instantiation: {module}.{cls}")
     mod = self.modulemgr.get_class_from_module(cls=cls, module=module)
-    instance = mod(context=self, args=args)
-    self._register_instance_secrets(instance, args)
-    return mod(context=self, args=args)
+    with mod(context=self, args=args) as instance:
+      self._register_instance_secrets(instance, args)
+      return instance
 
   def instantiate(self, module, cls, args):
     """Register the class to the ``laboro.module.ModuleMgr`` instance and return an instance of the class.
